@@ -10,8 +10,6 @@ from Accuinsight.modeler.protos import skapi_pb2
 from Accuinsight.modeler.utils.proto_json_utils import parse_dict
 from Accuinsight.modeler.utils.string_utils import strip_suffix
 from Accuinsight.modeler.exceptions import ModelerException, RestException
-from Accuinsight.modeler.core.Run.RunInfo.RunInfo import get_current_run
-from Accuinsight.modeler.core.LcConst.LcConst import RUN_RESULT_PATH, RUN_MODEL_SHAP_JSON_PATH
 
 RESOURCE_DOES_NOT_EXIST = 'RESOURCE_DOES_NOT_EXIST'
 
@@ -163,6 +161,7 @@ def _make_parameter_data(json_body):
 
     # get metrics
     parameter_data = json_body['parameter']
+
     # "parameter": {
     #     "parameter": {
     #       "learningrate": "0.12",
@@ -186,34 +185,13 @@ def _make_parameter_data(json_body):
     json_body['parameter'] = parameter
     return json_body
 
-def _make_feature_data(json_body):
-    json_body['feature'] = {}
-    json_body['feature']['importance'] = {}
-
-    run_info_json = get_current_run()
-    run_result_path = run_info_json[RUN_RESULT_PATH]
-
-    #json_path = run_result_path[RUN_MODEL_SHAP_JSON_PATH]
-
-    #json_path = None
-    
-    if RUN_MODEL_SHAP_JSON_PATH in run_result_path.keys():
-        json_path = run_result_path[RUN_MODEL_SHAP_JSON_PATH]
-
-        with open(json_path) as json_file:
-            shap_json_data = json.load(json_file)
-        json_body['feature']['importance'] = shap_json_data   
-
-    return json_body
-
 
 def call_endpoint(host_creds, endpoint, method, json_body, response_proto):
-    # Cover json String to json dictionary, to pass to requests
+    # Convert json string to json dictionary, to pass to requests
     if json_body:
         json_body = json.loads(json_body)
         json_body = _make_metrics_data(json_body)
         json_body = _make_parameter_data(json_body)
-        json_body = _make_feature_data(json_body)
     if method == 'GET':
         response = http_request(
             host_creds=host_creds, endpoint=endpoint, method=method, params=json_body)
@@ -222,7 +200,6 @@ def call_endpoint(host_creds, endpoint, method, json_body, response_proto):
             host_creds=host_creds, endpoint=endpoint, method=method, json=json_body)
     response = verify_rest_response(response, endpoint)
     js_dict = json.loads(response.text)
-    # print('Backend Response result: ', js_dict)
     parse_dict(js_dict=js_dict, message=response_proto)
     return response_proto
 
